import React, { Component } from 'react';
import { Flex, NavBar, List, WingBlank, Toast } from 'antd-mobile';
import { OrderItem } from '@/common/index';
import { Link } from 'react-router-dom';
import { http, api } from "@/utils";
import {throttle} from 'lodash';

import "./order.scss"

const Item = List.Item;

function OrderList(props) {
  const listData = props.list;
  return (
    <div>
      {
        listData.map((item, index) => {
          const Info = (
            <div className="order-info">
              <p className='order-title' style={{ overflow: 'hidden', textOverflow: 'ellipsis', whiteSpace: 'nowrap' }}>{item.course_title}</p>
              <p className='order-content' style={{ WebkitBoxOrient: 'vertical', WebkitLineClamp: '2', wordBreak: 'break-all', overflow: 'hidden', textOverflow: 'ellipsis', display: '-webkit-box' }}>{item.simpledescription}</p>
              <p className='order-des'>
                <span className='order-newprice'>¥{item.price1}</span>
                <span className='order-price'>¥{item.price0}</span>
              </p>
            </div>
          )

          return (
            <OrderItem {...item} key={index} info={Info}>
              <div className="order-prefer">
                <List key={index}>
                  <Item
                    arrow="horizontal"
                    onClick={() => { }}
                  >
                    <Link to='/coupons'>
                      <Flex justify='between'>
                        <span style={{color: '#333', fontSize: '15px'}}>优惠券</span>
                        <span style={{fontSize: '14px', color: '#999999'}}>{item.coupon_num === 0 ? '无' : `${item.coupon_num}张可用`}</span>
                      </Flex>
                    </Link>
                  </Item>
                </List>
              </div>
            </OrderItem>
          )
        })
      }
    </div>
  );
}

class Order extends Component {
  constructor(props) {
    super(props);
    this.state = {
      perfect: this.props.location.state,
      user_account: 0.00, // 账户余额
      total_sale: 0.00, // 需要支付总金额
      discount: 0.00, // 
      useBalance: false,
      orderList: [],
      info: false,
      offset: 0,
    }
  }
  // 提交订单
  submitOrder = () => {
    if (!this.state.perfect) {
      Toast.info('请完善报名信息！');
    }
    if(this.state.orderList.lengtjh === 0) {
      Toast.info('没有要提交的订单！');
      return;
    }
  }
  // 使用余额
  useBalance = () => {
    let useBalanceFlag = this.state.useBalance;
    this.setState({
      useBalance: !useBalanceFlag
    });
    if(!useBalanceFlag){
      this.cacheObj = {
        ...this.state
      }
    }
    // console.log(useBalance);
    let totalSale = parseFloat(this.cacheObj.total_sale),
        userAccount = parseFloat(this.cacheObj.user_account);
    if(!useBalanceFlag) {
      if(totalSale > userAccount) {
        this.setState({
          offset: userAccount.toFixed(2),
          total_sale: (totalSale - userAccount).toFixed(2),
          discount: userAccount.toFixed(2),
        });
      }else{
        this.setState({
          offset: totalSale.toFixed(2),
          total_sale: 0,
          discount: totalSale.toFixed(2),
        });
      }
    }else{
      this.setState({
        offset: this.cacheObj.offset,
        total_sale: this.cacheObj.total_sale,
        discount: this.cacheObj.discount,
      });
    }
    this.computedMoney();
  }
  // 计算金额、优惠金额、优惠券等
  computedMoney = () => {

  };
  // 展示余额抵扣规则
  showInfo = () => {
    this.setState((prevState)=>({
      info: !prevState.info
    }));
  };
  componentDidMount() {
    http.get(`${api.home}/m/order/preorder`).then((res) => {
      console.log(res);
      if (res.data.code !== 200) {
        return;
      }
      const { course, total_sale, user_account, user_info, discount } = res.data.data;
      this.dataCache = JSON.parse(JSON.stringify(res.data.data));
      console.log(course);
      this.setState({
        perfect: user_info,
        orderList: course, 
        user_account,
        total_sale,
        discount,
      });
    })

    // // 获取报名信息 获取课程列表 获取用户账户余额
    // Promise.race([http.get(), http.get(), http.get()]).then(res=>{

    // });
  };
  render() {
    const {
      perfect,
      orderList,
      user_account,
      total_sale,
      discount,
      useBalance,
      info,
      offset,
    } = this.state;

    return (
      <div className="order-wrapper">
        <Flex>
          <Flex.Item>
            <NavBar
              style={{ "height": "44px" }}
              className="order-tab"
              mode="light"
              icon={<i className="iconfont iconiconfront-68"></i>}
            >
              课程报名
                </NavBar>
            {
              !this.state.perfect &&
              <Link to='/orderinfo' className="order-information">
                <i className="iconfont iconiconfront-6 order-addsize"></i>
                <div className="order-infotext">完善报名信息</div>
                <i className="iconfont iconiconfront-70 order-next"></i>
              </Link>
            }
            {
              this.state.perfect &&
              <div className="order-information2">
                <WingBlank>
                  <Link to={{
                    pathname: '/orderinfo',
                    state: this.state.perfect
                  }
                  } >
                  <Flex align='center' justify='between' style={{ height: '80px' }}>
                    <i className="iconfont iconiconfront-20 user-icon"></i>

                    <Flex direction='column' justify='between' align='start' className="order-cell">
                      <div className="name">{`姓名：${perfect.real_name}`}</div>
                      <div>{`电话：${perfect.cellphone}`}</div>
                    </Flex>

                    <Flex align='start' className="order-cell">
                      <div>{`QQ：${perfect.qq}`}</div>
                    </Flex>

                  </Flex>
                  </Link>
                </WingBlank>
              </div>
            }
            <div className="order-list">
              <OrderList list={orderList} compute={this.computedMoney}/>
            </div>
            <div className="order-balance">
              <List>
                <Item
                  className="order-prefer-text"
                >
                  <Flex justify='between'>
                    <Flex align='center'>
                      <span>余额抵扣</span>
                      <span className="order-balanceprice"> (余额: <i className="order-money">{`${user_account}元`}</i>)</span>
                      <i className="iconfont iconiconfront-22" onClick={this.showInfo}></i>
                    </Flex>
                    {
                      useBalance ? (
                        <div>
                          <span style={{ color: '#FF2121', fontSize: '15px', marginRight: "6px" }}>{`-${offset}`}</span>
                          <i className="iconfont icondanseshixintubiao-5" onClick={throttle(this.useBalance, 600)}></i>
                        </div>
                      ) : (
                          <i className="iconfont iconiconfront-3" onClick={this.useBalance}></i>
                        )
                    }
                  </Flex>
                </Item>
              </List>
            </div>
            <div className="order-bar">
              <div className="order-course">
                <span className="order-course-text">{`${orderList.length}门课程`}</span>
              </div>
              <div className="order-bar-text">
                <div className="order-amount">
                  <span className="order-amount-title">合计:</span>
                  <span className="order-amount-price">{`￥${total_sale}`}</span>
                </div>
                <div className="order-preprice">
                  <span className="order-preprice-title">已优惠:</span>
                  <span className="order-preprice-price">{`¥${discount}`}</span>
                </div>
              </div>
              {
                perfect ? (

                  <button type="button" className="order-button has-info">
                    <span className="order-button-text" onClick={this.submitOrder}>提交订单</span>
                  </button>
                ) : (

                    <button type="button" className="order-button">
                      <span className="order-button-text" onClick={this.submitOrder}>提交订单</span>
                    </button>
                  )
              }
            </div>
          </Flex.Item>
        </Flex>
        {
          info ? (
            <div style={{ position: 'fixed', top: 0, left: 0, width: '100%', height: '100%', backgroundColor: 'rgba(0, 0, 0, 0.8)', zIndex: '99' }}>
              <div style={{ padding: '20px', backgroundColor: '#FFF', width: '300px', height: '170px', margin: '0 auto', position: 'absolute', left: '50%', top: '50%', transform: 'translate(-50%, -50%)' }}>
                <Flex direction='column' justify='between' align='center' style={{ height: '100%' }}>
                  <p style={{ fontSize: '16px', color: '#333333' }}>余额抵扣说明</p>
                  <p style={{ lineHeight: '20px', fontSize: '13px', color: '#666666' }}>分销课程或者参与七月在线的相关活动，可获得资金奖励。账户资金可直接提现，也可抵扣课程费用。</p>
                  <div onClick={this.showInfo} style={{ width: '260px', height: '30px', lineHeight: '30px', textAlign: 'center', borderRadius: '3px', border: '1px solid #0099FF', color: '#0099FF', fontSize: '15px' }}>知道了</div>
                </Flex>
              </div>
            </div>
          ) : null
        }
      </div>

    )
  }

}

export default Order;